<?php
/**
* Select tag PHP wrapper. Provides creation of SelectTag objects from arrays
* by one call.
*
* @access public
* @author Vladimir Sibirov <trustware@bk.ru>
* @package XTPL
*/
class SelectTag extends HtmlTag
{
        
        /**
        * Creates a new HtmlTag object from data array. $data_array can be of 2 types.
        *
        * First is simple enumerated or associative array. In this case array idexes will
        * be used as 'value' attributes for the options. And the values will be used as
        * content for the option tags.
        *
        * $countries['en'] = 'England';
        * $countries['ru'] = 'Russia';
        * $sel = new SelectTag('country', $countries);
        * $sel->Parse();
        * // Output: <select name="country"><option value="en">England</option><option value="ru">Russia></option></select>
        *
        * Another way it can process 2d arrays. The scheme is rather hard, but this was designed for
        * use with SDQLDB::RowTable() and SQLDB::ArrayTable() methods.
        *
        * $countries[0]['id'] = 'en';
        * $countries[0]['name'] = 'England';
        * $countries[1]['id'] = 'ru';
        * $countries[1]['name'] = 'Russia';
        * $sel = new SelectTag('country', $countries);
        * $sel->Parse();
        * // Output: <select name="country"><option value="en">England</option><option value="ru">Russia></option></select>
        *
        * @access public
        * @return SelectTag
        * @param string $name Name attribute for the select.
        * @param array $data_array Data.
        * @param int $checked Number of field which is checked.
        */
        function SelectTag($name, $data_array, $checked = 0)
        {
                $this->tag = 'select';
                $this->Attr['name'] = $name;
                if(is_array($data_array[0]))
                {
                        // Result of SQLDB ArrayTable() call
                        for($i = 0; $i < count($data_array); $i++)
                        {
                                $primary_key = true;
                                $is_checked = false;
                                $id = null;
                                $text = null;
                                foreach($data_array[$i] as $key => $val)
                                {
                                        if($primary_key)
                                        {
                                                $id = $val;
                                                $primary_key = false;
                                                if($id == $checked) $is_checked = true;
                                        }
                                        else $text = $val;
                                }
                                $option = new HtmlTag('option', $text);
                                $option->Attr['value'] = $id;
                                if($is_checked) $option->Attr['checked'] = 'checked';
                                $this->Insert($option);
                        }
                }
                elseif(is_array($data_array))
                {
                        // Simple associative array
                        $i = 0;
                        foreach($data_array as $key => $val)
                        {
                                $option = new HtmlTag('option', $val);
                                $option->Attr['value'] = $key;
                                if($i == $ckeced) $option->Attr['checked'] = 'checked';
                                $this->Insert($option);
                                $i++;
                        }
                }
        }
}
?>